from ..write_text import write_text


def parse_speed_description(json, origin):
    for speed in json.get("values", []):
        if "descriptions" in speed:
            descriptions = []
            if type(speed["descriptions"]) is list:
                descriptions = speed["descriptions"]
            else:
                descriptions.append(speed["descriptions"])
            for desc in descriptions:
                write_text(desc, origin,
                           comment="Speed description of monsters")



from ..helper import get_singular_name
from ..write_text import write_text


def parse_magazine(json, origin):
    write_text(json["name"], origin, comment="Magazine name", plural=True)
    name = get_singular_name(json["name"])

    if "description" in json:
        write_text(json["description"], origin,
                   comment="Description of magazine \"{}\"".format(name))

    if "variants" in json:
        for variant in json["variants"]:
            variant_name = get_singular_name(variant["name"])
            write_text(variant["name"], origin,
                       comment="Variant name of magazine \"{}\"".format(name),
                       plural=True)
            write_text(variant["description"], origin,
                       comment="Description of variant \"{0}\" "
                       "of magazine \"{1}\"".format(variant_name, name))



from ..write_text import write_text


def parse_activity_type(json, origin):
    if "verb" in json:
        write_text(json["verb"], origin,
                   comment="Verb in activity \"{}\"".format(json["id"]))



from ..write_text import write_text


def parse_shopkeeper_blacklist(json, origin):
    for entry in json["entries"]:
        if "message" in entry:
            comment = entry.get("//", None)
            write_text(entry["message"], origin,
                       comment=["Reason for a shopkeeper blacklist entry",
                                comment])
